Struct google_translate2::api::DetectionMethods
source · pub struct DetectionMethods<'a, S>where
S: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on detection resources.
It is not used directly, but through the Translate hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_translate2 as translate2;
use std::default::Default;
use translate2::{Translate, oauth2, hyper, hyper_rustls, chrono, FieldMask};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = Translate::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `detect(...)` and `list(...)`
// to build up your call.
let rb = hub.detections();Implementations
sourceimpl<'a, S> DetectionMethods<'a, S>
impl<'a, S> DetectionMethods<'a, S>
sourcepub fn detect(
&self,
request: DetectLanguageRequest
) -> DetectionDetectCall<'a, S>
pub fn detect( &self, request: DetectLanguageRequest ) -> DetectionDetectCall<'a, S>
Create a builder to help you perform the following task:
Detects the language of text within a request.
Arguments
request- No description provided.
sourcepub fn list(&self, q: &Vec<String>) -> DetectionListCall<'a, S>
pub fn list(&self, q: &Vec<String>) -> DetectionListCall<'a, S>
Create a builder to help you perform the following task:
Detects the language of text within a request.
Arguments
q- The input text upon which to perform language detection. Repeat this parameter to perform language detection on multiple text inputs.