pub struct DetectionsListResponse {
pub detections: Option<Vec<DetectionsResource>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- detect detections (response)
- list detections (response)
Fields
detections: Option<Vec<DetectionsResource>>A detections contains detection results of several text