Struct google_translate2::api::TranslationMethods
source · pub struct TranslationMethods<'a, S>where
S: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on translation resources.
It is not used directly, but through the Translate hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_translate2 as translate2;
use std::default::Default;
use translate2::{Translate, oauth2, hyper, hyper_rustls, chrono, FieldMask};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = Translate::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `list(...)` and `translate(...)`
// to build up your call.
let rb = hub.translations();Implementations
sourceimpl<'a, S> TranslationMethods<'a, S>
impl<'a, S> TranslationMethods<'a, S>
sourcepub fn list(&self, q: &Vec<String>, target: &str) -> TranslationListCall<'a, S>
pub fn list(&self, q: &Vec<String>, target: &str) -> TranslationListCall<'a, S>
Create a builder to help you perform the following task:
Translates input text, returning translated text.
Arguments
q- The input text to translate. Repeat this parameter to perform translation operations on multiple text inputs.target- The language to use for translation of the input text, set to one of the language codes listed in Language Support.
sourcepub fn translate(
&self,
request: TranslateTextRequest
) -> TranslationTranslateCall<'a, S>
pub fn translate( &self, request: TranslateTextRequest ) -> TranslationTranslateCall<'a, S>
Create a builder to help you perform the following task:
Translates input text, returning translated text.
Arguments
request- No description provided.