Struct google_translate2::DetectLanguageRequest [−][src]
The request message for language detection.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- detect detections (request)
Fields
q: Option<Vec<String>>
The input text upon which to perform language detection. Repeat this parameter to perform language detection on multiple text inputs.