Structs
- Detect
Language Request - The request message for language detection.
- Detection
Detect Call - Detects the language of text within a request.
- Detection
List Call - Detects the language of text within a request.
- Detection
Methods - A builder providing access to all methods supported on detection resources.
It is not used directly, but through the
Translatehub. - Detections
List Response - There is no detailed description.
- Detections
Resource - An array of languages which we detect for the given text The most likely language list first.
- Detections
Resource Nested - An array of languages which we detect for the given text The most likely language list first.
- Language
List Call - Returns a list of supported languages for translation.
- Language
Methods - A builder providing access to all methods supported on language resources.
It is not used directly, but through the
Translatehub. - Languages
List Response - There is no detailed description.
- Languages
Resource - There is no detailed description.
- Translate
- Central instance to access all Translate related resource activities
- Translate
Text Request - The main translation request message for the Cloud Translation API.
- Translation
List Call - Translates input text, returning translated text.
- Translation
Methods - A builder providing access to all methods supported on translation resources.
It is not used directly, but through the
Translatehub. - Translation
Translate Call - Translates input text, returning translated text.
- Translations
List Response - The main language translation response message.
- Translations
Resource - There is no detailed description.
Enums
- Scope
- Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.