Struct google_translate2::api::TranslationsResource [−][src]
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
detected_source_language: Option<String>The source language of the initial request, detected automatically, if no source language was passed within the initial request. If the source language was passed, auto-detection of the language will not occur and this field will be empty.
model: Option<String>The model type used for this translation. Valid values are
listed in public documentation. Can be different from requested model.
Present only if specific model type was explicitly requested.
translated_text: Option<String>Text translated into the target language.